@@ -84,8 +84,9 @@ def emotion (ask, url) :
     feel = 'nothing'
 
   if inp == 100:
-    val = input("Sorry I don't know about" + inp + " ,but I am Curious about it Can you please tell me, How you feel about it? (give the answer in 'angry','sad','scared','excited','happy','h-cited','nothing' :   "   )
-    l = val.lower()
+
+    print("Sorry I don't know about " + ask + " ,but I am Curious about it Can you please tell me, How you feel about it? (give the answer in 'angry','sad','scared','excited','happy','h-cited','nothing' : ")
+    l = input()
     if l == 'angry':
       kit = 4
       print('Thanks!')
@@ -121,14 +122,14 @@ def emotion (ask, url) :
   emotion.feelings = 'I am feeling '+ feel+ ' about ' + ask
   emotion.mood = 'mood:'+ ovimo
 
-def learn (input, emotion, url):
+def learn (input, feel, url):
 
 
   l = input
   kit = l
 
   knoutings = kit
-  emI = emotion
+  emI = feel
   from firebase import firebase
   firebase = firebase.FirebaseApplication(url, None)
   firebase.put('/knowlage', knoutings, emI)
